package com.phm.manage.service;

import com.phm.manage.domain.OrderInfo;

import java.util.List;

/**
 * 系统指令信息Service接口
 *
 * @author phm
 * @date 2023-08-31
 */
public interface IOrderInfoService {
    /**
     * 查询系统指令信息
     *
     * @param id 系统指令信息主键
     * @return 系统指令信息
     */
    public OrderInfo selectOrderInfoById(Long id);

    /**
     * 查询系统指令信息列表
     *
     * @param orderInfo 系统指令信息
     * @return 系统指令信息集合
     */
    public List<OrderInfo> selectOrderInfoList(OrderInfo orderInfo);

    /**
     * 新增系统指令信息
     *
     * @param orderInfo 系统指令信息
     * @return 结果
     */
    public int insertOrderInfo(OrderInfo orderInfo);

    /**
     * 修改系统指令信息
     *
     * @param orderInfo 系统指令信息
     * @return 结果
     */
    public int updateOrderInfo(OrderInfo orderInfo);

    /**
     * 批量删除系统指令信息
     *
     * @param ids 需要删除的系统指令信息主键集合
     * @return 结果
     */
    public int deleteOrderInfoByIds(Long[] ids);

    /**
     * 删除系统指令信息信息
     *
     * @param id 系统指令信息主键
     * @return 结果
     */
    public int deleteOrderInfoById(Long id);
}
